##  Step 2: Create Your Project Directory
To create a directory where you want to host your project, run the following command:

```
mkdir custom-reports-demo
```



To switch to the directory that you created, run the following command:

```
cd custom-reports-demo
```



